@@ -148,3 +148,33 @@ def render_analytics_code(anonymize_ip='anonymize'):
             settings, 'ANALYTICS_TRACKING_ID', 'UA-XXXXXXX-XX'),
         'anonymize_ip': anonymize_ip,
     }
+
+
+class VerbatimNode(template.Node):
+    def __init__(self, text):
+        self.text = text
+
+    def render(self, context):
+        return self.text
+
+
+@register.tag
+def verbatim(parser, token):
+    """Tag to render x-tmpl templates with Django template code."""
+    text = []
+    while 1:
+        token = parser.tokens.pop(0)
+        if token.contents == 'endverbatim':
+            break
+        if token.token_type == template.TOKEN_VAR:
+            text.append('{{ ')
+        elif token.token_type == template.TOKEN_BLOCK:
+            text.append('{%')
+        text.append(token.contents)
+        if token.token_type == template.TOKEN_VAR:
+            text.append(' }}')
+        elif token.token_type == template.TOKEN_BLOCK:
+            if not text[-1].startswith('='):
+                text[-1:-1] = [' ']
+            text.append(' %}')
+    return VerbatimNode(''.join(text))
